summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteprotocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteprotocol.h')
-rw-r--r--kopete/libkopete/kopeteprotocol.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopeteprotocol.h b/kopete/libkopete/kopeteprotocol.h
index 64cab27c..6160650a 100644
--- a/kopete/libkopete/kopeteprotocol.h
+++ b/kopete/libkopete/kopeteprotocol.h
@@ -86,7 +86,7 @@ public:
*
* @return A new AddContactPage to be shown in the Add Contact Wizard
*/
- virtual AddContactPage *createAddContactWidget( TQWidget *tqparent, Account *account ) = 0;
+ virtual AddContactPage *createAddContactWidget( TQWidget *parent, Account *account ) = 0;
/**
* @brief Create a new KopeteEditAccountWidget
@@ -94,13 +94,13 @@ public:
* @return A new KopeteEditAccountWidget to be shown in the account part of the configurations.
*
* @param account is the KopeteAccount to edit. If it's 0L, then we create a new account
* @param tqparent The tqparent of the 'to be returned' widget
*/
- virtual KopeteEditAccountWidget * createEditAccountWidget( Account *account, TQWidget *tqparent ) = 0;
+ virtual KopeteEditAccountWidget * createEditAccountWidget( Account *account, TQWidget *parent ) = 0;
/**
- * @brief a bittqmask of the capabilities of this protocol
+ * @brief a bitmask of the capabilities of this protocol
* @sa @ref setCapabilities
*/
unsigned int capabilities() const ;
@@ -161,10 +161,10 @@ protected:
* @brief Constructor for Protocol
*
* @param instance The protocol's instance, every plugin needs to have a KInstance of its own
* @param tqparent The protocol's tqparent object
* @param name The protocol's name
*/
- Protocol( KInstance *instance, TQObject *tqparent, const char *name );
+ Protocol( KInstance *instance, TQObject *parent, const char *name );
/**
* @brief Sets the capabilities of this protcol.
@@ -94,13 +94,13 @@ public:
*
* @param account is the KopeteAccount to edit. If it's 0L, then we create a new account
- * @param tqparent The tqparent of the 'to be returned' widget
+ * @param parent The parent of the 'to be returned' widget
*/
@@ -161,10 +161,10 @@ protected:
*
* @param instance The protocol's instance, every plugin needs to have a KInstance of its own
- * @param tqparent The protocol's tqparent object
+ * @param parent The protocol's parent object
* @param name The protocol's name
*/